@@ -4,7 +4,11 @@ import sys
 import textwrap
 
 import click
-import toml
+
+if sys.version_info.minor < 11:
+    import toml
+else:
+    import tomllib as toml
 
 HOST = pathlib.Path.home()
 CONFIG_PATH = pathlib.Path(HOST, ".config", "orc")
@@ -46,7 +50,7 @@ def merge(a: dict, b: dict):
     for key in a:
         if key in b:
             if isinstance(a[key], dict) and isinstance(b[key], dict):
-                a[key].update(b[key])
+                a[key].update(merge(a[key], b[key]))
             else:
                 a[key] = b[key]
 
